@@ -1,17 +1,5 @@
 var NAVTREEINDEX8 =
 {
-"classFl__Preferences.html#a20b8a66cd9fda6f727e391847653c4df":[4,0,101,11],
-"classFl__Preferences.html#a30e9d1ae031b06f501779c8937533740":[4,0,101,24],
-"classFl__Preferences.html#a3a1710633307e8e79ba8fd89a803042e":[4,0,101,18],
-"classFl__Preferences.html#a3bb397989a4485545d4d65709ce3c863":[4,0,101,47],
-"classFl__Preferences.html#a3d06e7b756a9c87acc508b835286d569":[4,0,101,42],
-"classFl__Preferences.html#a4009efec7d5505a8060ca7a95c1bee2e":[4,0,101,33],
-"classFl__Preferences.html#a402ba68241bfefeabcd3665613d81607":[4,0,101,9],
-"classFl__Preferences.html#a44b60d610214f1ff60e9603babdea664":[4,0,101,8],
-"classFl__Preferences.html#a49a5569fb0b4f270ff8b343f34d11eac":[4,0,101,12],
-"classFl__Preferences.html#a4b0188c9976139103b5c49761c8b765a":[4,0,101,29],
-"classFl__Preferences.html#a4d49e9959bc26fdc20641534497f3792":[4,0,101,23],
-"classFl__Preferences.html#a61bd91e8c3ee2a3f8bccd00ee2a65b8d":[4,0,101,21],
 "classFl__Preferences.html#a6602c3104b2c5259160cb7e0fe5dd335":[4,0,101,19],
 "classFl__Preferences.html#a6db9d28bd448a131448276ee03de1e6d":[4,0,101,46],
 "classFl__Preferences.html#a6ff11b679bec179ebb211c31f8e46f2e":[4,0,101,36],
@@ -169,26 +157,27 @@ var NAVTREEINDEX8 =
 "classFl__Round__Clock.html":[4,0,113],
 "classFl__Round__Clock.html#a60d305750a8a3643fc9705922f3f885e":[4,0,113,0],
 "classFl__Scroll.html":[4,0,114],
-"classFl__Scroll.html#a20e548a2e473e6606e5bbc0ef3d0be0d":[4,0,114,17],
-"classFl__Scroll.html#a3f0651126d937ff5e87a115c96b01e47":[4,0,114,10],
-"classFl__Scroll.html#a40c34a9fd755968a283e247fed068dd4":[4,0,114,15],
-"classFl__Scroll.html#a4328309a02ce7af89f569ef3e0314d80":[4,0,114,12],
-"classFl__Scroll.html#a478a6ac22848f80ae2b943f7bcd1ae89":[4,0,114,19],
-"classFl__Scroll.html#a5a43276723fda5cbd2b327fe65b06b7d":[4,0,114,18],
-"classFl__Scroll.html#a61837981c54cedc009b2e53deaa39719":[4,0,114,8],
-"classFl__Scroll.html#a83b1ac53e5d35d83b9b804e03891363a":[4,0,114,16],
-"classFl__Scroll.html#aa86d74a5b34bf14c704751ef8f4521d4":[4,0,114,11],
-"classFl__Scroll.html#abf250f7025a334faee0466ac752d5e5b":[4,0,114,7],
-"classFl__Scroll.html#ac319d7b60fc8a019a2a7d04446e464e3":[4,0,114,14],
-"classFl__Scroll.html#ae233e5c01f4d5e0a70bd04e6ea995c65":[4,0,114,9],
-"classFl__Scroll.html#af5037f13e08b7299f0c45b51f88705e8a03f3bca7b9640e2a8f0e1ff31fe6d4f8":[4,0,114,6],
-"classFl__Scroll.html#af5037f13e08b7299f0c45b51f88705e8a4b873bab7be947f316ba3460584253fd":[4,0,114,1],
-"classFl__Scroll.html#af5037f13e08b7299f0c45b51f88705e8a4bb1632c770866fdc7ed8585276ed44a":[4,0,114,3],
-"classFl__Scroll.html#af5037f13e08b7299f0c45b51f88705e8a5e529b94b7f4897f1ccbe9f1be66d7b2":[4,0,114,4],
-"classFl__Scroll.html#af5037f13e08b7299f0c45b51f88705e8aa86133f933846b5579f8cef4ddae10a6":[4,0,114,2],
-"classFl__Scroll.html#af5037f13e08b7299f0c45b51f88705e8aac33d5172b559df56ef253987a660e72":[4,0,114,0],
-"classFl__Scroll.html#af5037f13e08b7299f0c45b51f88705e8ab5cd556262cd4b1a1541ab3d9dea35a6":[4,0,114,5],
-"classFl__Scroll.html#afbf72e70c229d85bbd3716c21d43e5aa":[4,0,114,13],
+"classFl__Scroll.html#a20e548a2e473e6606e5bbc0ef3d0be0d":[4,0,114,19],
+"classFl__Scroll.html#a2792f4cac18bcbd8208f73a2d12d0f33a03f3bca7b9640e2a8f0e1ff31fe6d4f8":[4,0,114,7],
+"classFl__Scroll.html#a2792f4cac18bcbd8208f73a2d12d0f33a4b873bab7be947f316ba3460584253fd":[4,0,114,2],
+"classFl__Scroll.html#a2792f4cac18bcbd8208f73a2d12d0f33a4bb1632c770866fdc7ed8585276ed44a":[4,0,114,4],
+"classFl__Scroll.html#a2792f4cac18bcbd8208f73a2d12d0f33a5e529b94b7f4897f1ccbe9f1be66d7b2":[4,0,114,5],
+"classFl__Scroll.html#a2792f4cac18bcbd8208f73a2d12d0f33aa86133f933846b5579f8cef4ddae10a6":[4,0,114,3],
+"classFl__Scroll.html#a2792f4cac18bcbd8208f73a2d12d0f33aac33d5172b559df56ef253987a660e72":[4,0,114,1],
+"classFl__Scroll.html#a2792f4cac18bcbd8208f73a2d12d0f33ab5cd556262cd4b1a1541ab3d9dea35a6":[4,0,114,6],
+"classFl__Scroll.html#a3f0651126d937ff5e87a115c96b01e47":[4,0,114,11],
+"classFl__Scroll.html#a40c34a9fd755968a283e247fed068dd4":[4,0,114,17],
+"classFl__Scroll.html#a4328309a02ce7af89f569ef3e0314d80":[4,0,114,14],
+"classFl__Scroll.html#a478a6ac22848f80ae2b943f7bcd1ae89":[4,0,114,21],
+"classFl__Scroll.html#a5a43276723fda5cbd2b327fe65b06b7d":[4,0,114,20],
+"classFl__Scroll.html#a6084ec3aef85192dd0fe18b001f87ecc":[4,0,114,13],
+"classFl__Scroll.html#a61837981c54cedc009b2e53deaa39719":[4,0,114,9],
+"classFl__Scroll.html#a83b1ac53e5d35d83b9b804e03891363a":[4,0,114,18],
+"classFl__Scroll.html#aa86d74a5b34bf14c704751ef8f4521d4":[4,0,114,12],
+"classFl__Scroll.html#abf250f7025a334faee0466ac752d5e5b":[4,0,114,8],
+"classFl__Scroll.html#ac319d7b60fc8a019a2a7d04446e464e3":[4,0,114,16],
+"classFl__Scroll.html#ae233e5c01f4d5e0a70bd04e6ea995c65":[4,0,114,10],
+"classFl__Scroll.html#afbf72e70c229d85bbd3716c21d43e5aa":[4,0,114,15],
 "classFl__Scrollbar.html":[4,0,115],
 "classFl__Scrollbar.html#a1d35a3b6cf6d4a1ddfec35e78d61aa01":[4,0,115,6],
 "classFl__Scrollbar.html#a33366defaaeb1fde41271dd54f8ae512":[4,0,115,8],
@@ -249,5 +238,16 @@ var NAVTREEINDEX8 =
 "classFl__Slider.html#a6252acddd4e852ac79c79ee45ee2f726":[4,0,121,10],
 "classFl__Slider.html#a6db677f1a888946916d3b8e36547a646":[4,0,121,11],
 "classFl__Slider.html#ac58f77c7d7bb66a3f0fd4cf1c691b32f":[4,0,121,2],
-"classFl__Slider.html#ae7f415daaa4fd847ea9998c2917e6df6":[4,0,121,6]
+"classFl__Slider.html#ae7f415daaa4fd847ea9998c2917e6df6":[4,0,121,6],
+"classFl__Slider.html#aea633a4c884aa5c3627c25a36e69c103":[4,0,121,1],
+"classFl__Slider.html#aeda9efe572a5151dca87b41ac98cd6e5":[4,0,121,8],
+"classFl__Spinner.html":[4,0,122],
+"classFl__Spinner.html#a097aa9ffdaf9540edae5e3c61b9beb39":[4,0,122,20],
+"classFl__Spinner.html#a179c83b7271d1262b34416f14994fdb6":[4,0,122,19],
+"classFl__Spinner.html#a1ac14536a5fe0db55eecbef15d72f9f9":[4,0,122,17],
+"classFl__Spinner.html#a1b32857ea232fc5ee35a909a34ded596":[4,0,122,29],
+"classFl__Spinner.html#a1fe98a9f1f70debc751fea87b8679b0c":[4,0,122,26],
+"classFl__Spinner.html#a21f4de98602bf1967aca0ebb20ed1235":[4,0,122,15],
+"classFl__Spinner.html#a25ee41559aa71f3c1e9d9431d2389348":[4,0,122,3],
+"classFl__Spinner.html#a3348ad34207e58ac31e21fe279509f5d":[4,0,122,30]
 };
